import { ref } from 'vue'
import { throttle } from 'lodash-es'

export function useBackBottom(cb: () => void) {
  const visible = ref(false)
  const lastScrollTop = ref(0)

  function clickBackBottom() {
    visible.value = false
    cb()
  }

  function handleScrollMessageContainer(e: Event) {
    const target = e.target as HTMLElement

    const currentScrollTop = target.scrollTop

    // 向上滚动，显示返回底部图标
    if (currentScrollTop < lastScrollTop.value) {
      visible.value = true
    }

    // 是否滚动触底
    if (currentScrollTop + target.clientHeight >= target.scrollHeight - 5) {
      visible.value = false
    }

    lastScrollTop.value = currentScrollTop
  }

  const throttleScrollMessageContainer = throttle(handleScrollMessageContainer, 100, { leading: true })

  return { visible, clickBackBottom, throttleScrollMessageContainer }
}
